@@ -1,6 +1,19 @@
 import traceback
+import pprint
 from .. utils import FireStoreBase
 
+class FirestoreEventParsingError(Exception):
+    def __init__(self, message, fsChangeRec):
+        super().__init__(message)
+        self.fsChangeRec = fsChangeRec
+    
+    def __str__(self):
+        msg = f"{self.message}\n\n{repr(self.fsChangeRec)}"
+        return msg
+    
+    def __repr__(self):
+        return self.__str__()
+
 class FirestoreChangeRec(object):
     '''
     Processing a trigger event
@@ -38,6 +51,22 @@ class FirestoreChangeRec(object):
         
         if self.changeDataSummary['after'] is None:
             self.changeDataSummary['action'] = 'delete'
+    
+    def __repr__(self):
+        msgArr = []
+        msgArr.append(f"Event Action: {self.action}")
+        msgArr.append(f"Did Change: {self.didChange}")
+        msgArr.append(f"Path: {self.path}")
+        msgArr.append(f"UpdateTime: {self.updateTime}")
+        msgArr.append(f"createTime: {self.createTime}")
+        msgArr.append(f"Current Object: {pprint.pformat(self.currentObject())}")
+        msgArr.append(f"Prior Object: {pprint.pformat(self.priorObject())}")
+        msgArr.append(f"Event Object: {pprint.pformat(self.event)}")
+        objectStr = "\n".join(msgArr)
+        return objectStr
+    
+    def __str__(self):
+        return self.__repr__()
         
     def currentObject(self):
         if self.isDeleted:
@@ -45,6 +74,8 @@ class FirestoreChangeRec(object):
         return self.changeDataSummary['after']
     
     def priorObject(self):
+        if self.changeDataSummary['before'] is None:
+            return {}
         return self.changeDataSummary['before']
     
     def data(self,current=True):
@@ -69,7 +100,7 @@ class FirestoreChangeRec(object):
     
     @property
     def action(self):
-        self.changeDataSummary['action']
+        return self.changeDataSummary['action']
         
     @property
     def isDeleted(self):
@@ -97,10 +128,8 @@ class FirestoreChangeRec(object):
         try:
             return self._processUpdate(processValue)
         except Exception as e:
-            print(f"Error processing the {processValue} in the event.")
-            print(self.event[processValue])
-            msg = traceback.format_exc()
-            print(msg)
+            msg = f"Error processing the {processValue} in the event."
+            raise FirestoreEventParsingError(msg,self) from e
         
     def _processUpdate(self,processValue):
         updateDict = self.event[processValue]
