@@ -1411,6 +1411,8 @@ class ItemMonth(SalesInvBase):
             self._item = self.get_recipe_item_by_id(self.item_id)
             if self._item is not None and self._item['type'] is not None:
                 del self._item['type']
+            if self._item is None:
+                self._item = {}
         return self._item
 
     @property
@@ -1620,7 +1622,7 @@ class ItemMonth(SalesInvBase):
     @property
     def name(self):
         if self.item is None:
-            self.item = {}
+            self._item = {}
             return "No Item Name"
         return self.item.get('name',"No Item Name")
 
