@@ -152,7 +152,8 @@ class ItemReserve(SalesInvBase):
         return self._reserve_date
     
     def update_inventory_location(self,invLoc):
-        self._inventory_location = invLoc
+        if self.isNotEmptyNull(invLoc):
+            self._inventory_location = invLoc
         #  Inventory Location can be set from Reserve, Item and Location 10/26/2021
         #if self.location is not None:
         #    self.location['inventory_location'] = invLoc
@@ -168,18 +169,18 @@ class ItemReserve(SalesInvBase):
     @classmethod
     def GetDefaultInventoryLocationById(cls, item_id, location_id):
         def_inv_loc = ItemReserve.GetInvLocationFromSBObj(StorageBlob.getInstanceByDNL(item_id))
-        if def_inv_loc is None:
+        if cls.IsEmptyNull(def_inv_loc):
             def_inv_loc = ItemReserve.GetInvLocationFromSBObj(StorageBlob.getInstanceByDNL(location_id))
-            if def_inv_loc is None:
+            if cls.IsEmptyNull(def_inv_loc):
                 def_inv_loc = InventoryLocation.getInstance().default_location
         return def_inv_loc
 
     @classmethod
     def GetDefaultInventoryLocationByPath(cls, item_path, location_path):
         def_inv_loc = ItemReserve.GetInvLocationFromSBObj(StorageBlob.getInstanceByPath(item_path))
-        if def_inv_loc is None:
+        if cls.IsEmptyNull(def_inv_loc):
             def_inv_loc = ItemReserve.GetInvLocationFromSBObj(StorageBlob.getInstanceByPath(location_path))
-            if def_inv_loc is None:
+            if cls.IsEmptyNull(def_inv_loc):
                 def_inv_loc = InventoryLocation.getInstance().default_location
         return def_inv_loc
 
@@ -190,7 +191,8 @@ class ItemReserve(SalesInvBase):
     def refresh_inventory_location(self):
         if self._inv_loc_override == False:
             def_inv_loc = self.getDefaultInventoryLocation()
-            self.update_inventory_location(def_inv_loc)
+            if self.isNotEmptyNull(def_inv_loc):
+                self.update_inventory_location(def_inv_loc)
     
     def duplicate_reserve(self, inv_loc=None):
         docRef = self._growWeekParent.get_reserve_reference() #gwParent.get_reserve_reference()
@@ -389,8 +391,15 @@ class ItemReserve(SalesInvBase):
             item = cls.GetItemInfo(itemObj)
 
             if location is None:
-                locObj = cls.GetSbInstanceByPath(itemObj.parent_doc_path)
-                location = cls.GetLocInfo(locObj)
+                if itemObj.data_type != 'Copies':
+                    locObj = cls.GetSbInstanceByPath(itemObj.parent_doc_path)
+                    location = cls.GetLocInfo(locObj)
+                else:
+                    print("!! WARNING !! This is a custom item and the location is being pulled from original item path")
+                    fsDoc = FSDocument.getInstance(itemObj.orig_path)
+                    locObj = cls.GetSbInstanceByPath(fsDoc.location_path)
+                    location = cls.GetLocInfo
+                    
             if customer is None:
                 if locObj is not None:
                     custObj = cls.GetSbInstanceByPath(locObj.parent_doc_path)
@@ -475,7 +484,7 @@ class ItemReserve(SalesInvBase):
         # Update 10/26/2021:  No matter if it was passed or not... go get it
         default_inv_location = ir.getDefaultInventoryLocation()
 
-        if inventory_location is None:
+        if ItemReserve.IsEmptyNull(inventory_location):
             # if it wasn't passed in...grab get Default Value
             inventory_location = default_inv_location
         
@@ -494,19 +503,22 @@ class ItemReserve(SalesInvBase):
         return ir
 
     def set_inventory_location(self,inventory_location):
-        self.update_inventory_location(inventory_location)
-        self.update_ndb()
+        if self.isNotEmptyNull(inventory_location):
+            self.update_inventory_location(inventory_location)
+            self.update_ndb()
 
     def update_reserve(self, customer_id, location_id, item_id, reserved, gwParent, reserveDate=None, inventory_location=None):
         
         if gwParent.id != self.finish_week:
             self.delete_resp()
             docRef = gwParent.get_reserve_reference()
-            return ItemReserve.create_reserve(docRef, customer_id, location_id, item_id, reserved, gwParent.id, reserveDate, inventory_location)
+            newIr = ItemReserve.create_reserve(docRef, customer_id, location_id, item_id, reserved, gwParent.id, reserveDate, inventory_location)
+            newIr.custom_plant_item = self.custom_plant_item   #Make sure to preserve the fact that the original had a custom item
+            return newIr
 
         # if it was passed in... use it
         default_inv_location = self.getDefaultInventoryLocation()
-        if inventory_location is None:
+        if self.isEmptyNull(inventory_location):
             # if it wasn't passed in...grab get Default Value
             inventory_location = default_inv_location
             self.update_inventory_location(inventory_location)
@@ -515,7 +527,9 @@ class ItemReserve(SalesInvBase):
                 # Rather than try to fix everything... delete and recreate
                 self.delete_resp()
                 docRef = gwParent.get_reserve_reference()
-                return ItemReserve.create_reserve(docRef, customer_id, location_id, item_id, reserved, gwParent.id, reserveDate, inventory_location)
+                newIr = ItemReserve.create_reserve(docRef, customer_id, location_id, item_id, reserved, gwParent.id, reserveDate, inventory_location)
+                newIr.custom_plant_item = self.custom_plant_item #Make sure to preserve the fact that the original had a custom item
+                return newIr
         
         if default_inv_location != inventory_location:
             #
