@@ -377,6 +377,23 @@ class FireStoreBase(metaclass=ABCMeta):
         if dd is None:
             dd = {}
         return dd
+    
+    @classmethod
+    def IsEmptyNull(cls, value):
+        if value is None:
+            return True
+        strValue = str(value).strip()
+        return strValue == ''
+    
+    @classmethod
+    def IsNotEmptyNull(cls, value):
+        return not cls.IsEmptyNull(value)
+    
+    def isEmptyNull(self, value):
+        return FireStoreBase.IsEmptyNull(value)
+    
+    def isNotEmptyNull(self, value):
+        return not self.isEmptyNull(value)
 
     @classmethod
     def CheckFloat(cls,inNum):
